@@ -53,6 +53,7 @@ pub enum OpCode {
     GASLIMIT = 0x45,
     CHAINID = 0x46,
     SELFBALANCE = 0x47,
+    BASEFEE = 0x48,
     POP = 0x50,
     MLOAD = 0x51,
     MSTORE = 0x52,
@@ -199,6 +200,7 @@ impl fmt::Display for OpCode {
             OpCode::GASLIMIT => write!(f, "GASLIMIT"),
             OpCode::CHAINID => write!(f, "CHAINID"),
             OpCode::SELFBALANCE => write!(f, "SELFBALANCE"),
+            OpCode::BASEFEE => write!(f, "BASEFEE"),
             OpCode::POP => write!(f, "POP"),
             OpCode::MLOAD => write!(f, "MLOAD"),
             OpCode::MSTORE => write!(f, "MSTORE"),
@@ -374,6 +376,7 @@ impl OpCode {
             0x45 => Some(OpCode::GASLIMIT),
             0x46 => Some(OpCode::CHAINID),
             0x47 => Some(OpCode::SELFBALANCE),
+            0x48 => Some(OpCode::BASEFEE),
             0x50 => Some(OpCode::POP),
             0x51 => Some(OpCode::MLOAD),
             0x52 => Some(OpCode::MSTORE),
@@ -521,6 +524,7 @@ impl OpCode {
             OpCode::GASLIMIT => GasPriceTier::Base,
             OpCode::CHAINID => GasPriceTier::VeryLow,
             OpCode::SELFBALANCE => GasPriceTier::Low,
+            OpCode::BASEFEE => GasPriceTier::Base,
             OpCode::POP => GasPriceTier::Base,
             OpCode::MLOAD => GasPriceTier::VeryLow,
             OpCode::MSTORE => GasPriceTier::VeryLow,
@@ -667,6 +671,7 @@ impl OpCode {
             OpCode::GASLIMIT => 0,
             OpCode::CHAINID => 0,
             OpCode::SELFBALANCE => 0,
+            OpCode::BASEFEE => 0,
             OpCode::POP => 1,
             OpCode::MLOAD => 1,
             OpCode::MSTORE => 2,
@@ -813,6 +818,7 @@ impl OpCode {
             OpCode::GASLIMIT => 1,
             OpCode::CHAINID => 1,
             OpCode::SELFBALANCE => 1,
+            OpCode::BASEFEE => 1,
             OpCode::POP => 0,
             OpCode::MLOAD => 1,
             OpCode::MSTORE => 0,
@@ -959,6 +965,7 @@ impl OpCode {
             OpCode::GASLIMIT => false,
             OpCode::CHAINID => false,
             OpCode::SELFBALANCE => false,
+            OpCode::BASEFEE => false,
             OpCode::POP => false,
             OpCode::MLOAD => false,
             OpCode::MSTORE => false,
